def Int_to_Roman(s):
	res = 0; prev = 0
	save = {
	"I" : 1,
	"V" : 5,
	"X" : 10,
	"L" : 50,
	"C" : 100,
	"M" : 1000
	}
	for i in reversed(s):
		if save[i] >= prev:
			res += save[i]
		else:
			res -= save[i]
		prev = save[i]

	print(f"The number you entered in roman form is {res}")


import setuptools
setuptools.setup(
name = 'Leetease',
version = '0.01',
description = "This makes LeetCode Interview programs easy",
long_description = "This Python Package Helps Python Programmers Crack LeetCode programs with just 2 lines of code",
author = "SaatwikCodz",
packages = ['Leetease'],
install_requires = []
	)